Pootle Documentation — Pootle 2.8.0b4 documentation

# Pootle Documentation

Pootle is an online tool that makes the process of translating so much simpler. It allows crowd-sourced translations, easy volunteer contribution and gives statistics about the ongoing work.

Pootle is built using the powerful API of the Translate Toolkit and the Django framework. If you want to know more about these, you can dive into their own documentation.

- Translate Toolkit Documentation
- Django Documentation

## All you need to know

The following pages cover the documentation of Pootle from a wide variety of perspectives, server administrator’s, and developer’s view.

- Features
  - Pootle FS
  - Backends and storage
  - Online translation editor
  - Administrative features

- Installation
- Upgrading
- Administering a server
- Developers

## Additional Notes

- Release Notes
- License